@@ -141,7 +141,7 @@ class Data_inegrator:
                                           ascending=False)
             configuration_best_result = min(average_validation_sample_loss_per_epoch)
             print('The model best loss achieved on the validation set is : {}  '.format(configuration_best_result))
-            best_results_of_each_configuration.append(configuration)
+            best_results_of_each_configuration.append(configuration_best_result)
 
         configuration_results_df = pd.DataFrame(self.configuration_list)
         configuration_results_df = configuration_results_df.assign(best_loss=best_results_of_each_configuration)
